@@ -4,7 +4,7 @@ use strict;
 
 BEGIN {
 	$App::mkdist::AUTHORITY = 'cpan:TOBYINK';
-	$App::mkdist::VERSION   = '0.013';
+	$App::mkdist::VERSION   = '0.014';
 }
 
 use Carp;
@@ -160,7 +160,7 @@ sub set_defaults
 		if (@mr)
 		{
 			$self->{requires} = sprintf(
-				";\n\t:runtime_requires %s",
+				";\n\t:runtime-requirement %s",
 				(join ' , ', (map { my ($pkg, $ver) = split /\s+/, $_; ($ver =~ /^v?[0-9\._]+/) ? "[ :on \"$pkg $ver\"^^:CpanId ]" : "[ :on \"$pkg\"^^:CpanId ]" } @mr))
 			);
 		}
